import { type ActionReturnType, actions } from 'astro:actions';
import { writable } from 'svelte/store';
import { actionErrorPopup } from '@util/action.ts';

// types
export type Teams = Exclude<ActionReturnType<typeof actions.team.teams>['data'], undefined>['teams'];
export type Team = Teams[0];

export type Users = Exclude<ActionReturnType<typeof actions.user.users>['data'], undefined>['users'];

// state
export const teams = writable<Teams>([]);

// actions
export async function fetchTeams(name: string | null, username: string | null) {
  const { data, error } = await actions.team.teams({ name: name, username: username });
  if (error) {
    actionErrorPopup(error);
    return;
  }

  teams.set(data.teams);
}

export async function addTeam(team: Team) {
  const { data, error } = await actions.team.addTeam(team);
  if (error) {
    actionErrorPopup(error);
    return;
  }

  teams.update((old) => {
    old.push(Object.assign(team, { id: data.id }));
    return old;
  });
}

export async function editTeam(team: Team) {
  const { error } = await actions.team.editTeam(team);
  if (error) {
    actionErrorPopup(error);
    return;
  }

  teams.update((old) => {
    const index = old.findIndex((a) => a.id == team.id);
    old[index] = team;
    return old;
  });
}
